@@ -19,20 +19,6 @@ import sys
 
 from . import gui
 
-# Generic ac magnetometer file header names
-# DO NOT CHANGE ORDER.
-# Used in
-# - from_file() classmethod of Experiment in ac.py
-# - ac_mode_func() in cli.py
-
-HEADERS_GENERIC = [
-    "field",
-    "temperature",
-    "sus_real",
-    "sus_imaginary",
-    "ac_freq",
-    "ac_field"
-]
 
 # list of supported ac headers
 # These differ between magnetometers
@@ -45,11 +31,6 @@ HEADERS_SUPPORTED = {
     'temperature': [
         'Temperature (K)'
     ],
-    'ac_freq': [
-        'Wave Frequency (Hz)',
-        'AC Frequency (Hz)',
-        'Frequency (Hz)'
-    ],
     'sus_real': [
         "m' (emu)",
         "AC X'  (emu/Oe)",
@@ -64,6 +45,11 @@ HEADERS_SUPPORTED = {
         'M\'\' (emu)',
         "AC X'' (emu/Oe)"
     ],
+    'ac_freq': [
+        'Wave Frequency (Hz)',
+        'AC Frequency (Hz)',
+        'Frequency (Hz)'
+    ],
     'ac_field': [
         'Drive Amplitude (Oe)',
         'AC Drive (Oe)',
@@ -71,6 +57,9 @@ HEADERS_SUPPORTED = {
     ]
 }
 
+# Generic ac magnetometer file header names
+HEADERS_GENERIC = HEADERS_SUPPORTED.keys()
+
 
 def locate_data_header(file: str, data_header: str = '[Data]') -> int:
     """
@@ -147,7 +136,7 @@ def parse_headers(file: str,
                     header_indices[key] = hit
                     header_names[key] = header
 
-    return header_indices, header_names, HEADERS_SUPPORTED
+    return header_indices, header_names
 
 
 class ModelStore():
@@ -312,7 +301,7 @@ class Model(ABC):
 
     @staticmethod
     def from_experiments(experiments: list['Experiment'],
-                         verbose: bool = True) -> list['Model']:
+                         verbose: bool = False) -> list['Model']:
         """
         Creates one model object per experiment, where the type of model
         is set according to user input based on cole cole plot
@@ -358,16 +347,8 @@ class Model(ABC):
 
         Parameters
         ----------
-        temps : list
-            2-tuples specifying index and value of temperaure. Index is used to
-            discriminate which chi' and chi'' are used.
-        sus_res : np.ndarray
-            chi' values in cm3 mol-1
-        sus_ims : np.ndarray
-            chi'' values in cm3 mol-1
-        field : float
-            dc field strength in Oe
-
+        experiments: list[Experiment]
+            List of experiments to plot
         Returns
         -------
         Model
@@ -377,6 +358,7 @@ class Model(ABC):
         temperatures = [
             experiment.temperatures[0] for experiment in experiments
         ]
+
         field = experiments[0].dc_field
 
         colors = cm.coolwarm(np.linspace(0, 1, len(temperatures)))
@@ -577,15 +559,17 @@ class Model(ABC):
                 continue
 
             freq_grid = np.logspace(
-                np.log10(np.min(experiment.ac_freq*2*np.pi)),
-                np.log10(np.max(experiment.ac_freq*2*np.pi)),
+                np.log10(np.min(experiment.ac_freq)),
+                np.log10(np.max(experiment.ac_freq)),
                 100
             )
 
             f.write('{:11} {:.5f}\n'.format('T = ', model.fit_temperature))
 
             # Get model values at provided frequencies
-            [chips, chipps] = model.model(model.fitted_params, freq_grid)
+            [chips, chipps] = model.model(
+                model.fitted_params, freq_grid*2*np.pi
+            )
 
             f.write(model.MODELHEADERS)
             for freq, chip, chipp in zip(freq_grid, chips, chipps):
@@ -789,23 +773,28 @@ class Model(ABC):
 
             count += 1
 
+            # Plots will be in linear frequency to compare to experiment
             freq_grid = np.logspace(
-                np.log10(np.min(experiment.ac_freq*2*np.pi)),
-                np.log10(np.max(experiment.ac_freq*2*np.pi)),
+                np.log10(np.min(experiment.ac_freq)),
+                np.log10(np.max(experiment.ac_freq)),
                 100
             )
 
             # Get model values at provided frequencies
-            [chips, chipps] = model.model(model.fitted_params, freq_grid)
+            # Model takes angular frequencies
+            [chips, chipps] = model.model(
+                model.fitted_params,
+                freq_grid*2.*np.pi
+            )
 
             # Real
             ax2.semilogx(
-                experiment.ac_freq*2*np.pi,
+                experiment.ac_freq,
                 experiment.sus_re,
                 'o',
                 markersize=4,
                 fillstyle='none',
-                label='{:.2f} K'.format(model.fit_temperature),
+                label='{:.1f} K'.format(model.fit_temperature),
                 color=colors(ratio[count])
             )
             ax2.semilogx(
@@ -817,12 +806,12 @@ class Model(ABC):
             )
             # Imaginary
             ax3.semilogx(
-                experiment.ac_freq*2*np.pi,
+                experiment.ac_freq,
                 experiment.sus_im,
                 'o',
                 markersize=4,
                 fillstyle='none',
-                label='{:.2f} K'.format(model.fit_temperature),
+                label='{:.1f} K'.format(model.fit_temperature),
                 color=colors(ratio[count])
             )
             ax3.semilogx(
@@ -1296,7 +1285,7 @@ class GeneralisedDebyeModel(Model):
                 ))
             f.write('\n')
 
-        print("\nFit information has been written to {}\mn".format(
+        print("\nFit information has been written to {}\n".format(
             file_name
         ))
 
@@ -1538,43 +1527,42 @@ class TwoMaximaModel(Model):
         return
 
 
-def find_mean_temperatures(temperatures: list[float], temp_thresh: float = 0.1
-                           ) -> tuple[list[float], list[int]]:
+def find_mean_values(values: list[float], thresh: float = 0.1) -> tuple[
+        list[float], list[int]]:
     """
-    Finds mean temperatures from a list of temperatures by locating
-    values for which step size is >= `temp_thresh`
+    Finds mean value from a list of values by locating
+    values for which step size is >= `thresh`
 
     Returns list of same length with all values replaced by mean(s)
 
     Parameters
     ----------
-    temperatures: list[float]
-        Temperature values
-    temp_thresh: float, default 0.1
-        Threshold used to discriminate between temperatures
+    values: list[float]
+        Values to look at
+    thresh: float, default 0.1
+        Threshold used to discriminate between values
 
     Returns
     -------
     list[float]
-        Mean temperature values
+        Mean values
     list[int]
-        indices of original list at which temperature changes by more than
+        indices of original list at which value changes by more than
         0.1
     """
 
-    # Find values for which step size is >= temp_thresh
-
-    mask = np.abs(np.diff(temperatures)) >= temp_thresh
+    # Find values for which step size is >= thresh
+    mask = np.abs(np.diff(values)) >= thresh
     # and mark indices at which to split
     split_indices = np.where(mask)[0]
 
     # For values with similar step size, record mean temperature
-    mean_temps = [
+    means = [
         [np.mean(grp)]*grp.size
-        for grp in np.split(temperatures, split_indices + 1)
+        for grp in np.split(values, split_indices + 1)
     ]
 
-    return mean_temps, split_indices
+    return means, split_indices
 
 
 class Measurement():
@@ -1596,8 +1584,6 @@ class Measurement():
         linear ac frequency of experiment
     ac_field : float
         ac field
-    round_field : int
-        Number of decimal places to round dc field to
 
     Attributes
     ----------
@@ -1613,20 +1599,26 @@ class Measurement():
         imaginary part of susceptibility
     ac_field : float
         ac field
-    round_field : int
-        Number of decimal places to round dc field to
     mean_temperature : float
         Mean or representative temperature assigned to this experiment
+    mean_dc_field : float
+        Mean or representative dc field assigned to this experiment
     """
 
     def __init__(self, dc_field, temperature, sus_re,
-                 sus_im, ac_freq, ac_field, round_field):
-        self.dc_field = round(float(dc_field), round_field)
+                 sus_im, ac_freq, ac_field):
+
+        self.dc_field = dc_field
         self.temperature = temperature
         self.sus_re = sus_re
         self.sus_im = sus_im
-        self.ac_field = ac_field
         self.ac_freq = ac_freq
+        self.ac_field = ac_field
+
+        self.mean_temperature = None
+        self._mean_dc_field = None
+
+        return
 
     def convert_susc(self, in_susc_units, mw, mass):
         """
@@ -1651,21 +1643,25 @@ class Measurement():
             self.sus_im *= mw/(self.ac_field*mass/1000.)
         return
 
-    def set_mean_temp(self, value: float) -> None:
-        """
-        Sets mean or representative value of temperature for this
-        experiment
-
-        Parameters
-        ----------
-        value : float
-            mean value
-
-        """
-        self.mean_temperature = value
+    @property
+    def mean_temperature(self):
+        return self._mean_temperature
 
+    @mean_temperature.setter
+    def mean_temperature(self, value: float):
+        self._mean_temperature = value
         return
 
+    @property
+    def mean_dc_field(self):
+        return self._mean_dc_field
+
+    @mean_dc_field.setter
+    def mean_dc_field(self, value: float):
+        self._mean_dc_field = value
+        return
+
+    @staticmethod
     def check_pos_sus(s):
         try:
             s = float(s.strip())
@@ -1683,7 +1679,7 @@ class Measurement():
         """
         Extracts ac susceptibility from magnetometer output file and
         returns list of experiments, one for each valid measurment
-        Incomplete lines and negatvie values of susceptibility are ignored
+        Incomplete lines and negative values of susceptibility are ignored
 
         Parameters
         ----------
@@ -1702,20 +1698,17 @@ class Measurement():
             List has the same order as the magnetometer file
         """
 
-        # Columns to extract from file - n.b. these are ordered
-        # cols = [header_indices[gen] for gen in HEADERS_GENERIC]
-        cols = list(header_indices.values())
+        # Columns to extract from file
+        cols = [header_indices[gen] for gen in HEADERS_GENERIC]
 
         # Convert strings to floats, if not possible then mark as NaN
         converters = {
             it: lambda s: (float(s.strip() or np.NaN)) for it in cols
         }
 
-        # sus_real and sus_imaginary, defined in HEADERS_GENERIC
-        real_sus = list(header_indices.keys())[2]
-        imaginary_sus = list(header_indices.keys())[3]
-        converters[header_indices[real_sus]] = cls.check_pos_sus
-        converters[header_indices[imaginary_sus]] = cls.check_pos_sus
+        # Check for positive susceptibility
+        converters[header_indices['sus_real']] = cls.check_pos_sus
+        converters[header_indices['sus_imaginary']] = cls.check_pos_sus
 
         # Read required columns of file
         data = np.loadtxt(
@@ -1730,9 +1723,8 @@ class Measurement():
         # line
         # Check for missing entries which have been marked as NaN
         # and skip if found
-
         measurements = [
-            cls(*row, round_field=2)
+            cls(*row)
             for row in data
             if not any(isnan(val) for val in row)
         ]
@@ -1788,9 +1780,9 @@ class Experiment():
     def from_measurements(cls,
                           measurements: list[Measurement],
                           temp_thresh: float = 0.1,
-                          field_thresh: float = 1e-8) -> list[list['Experiment']]: # noqa
+                          field_thresh: float = 1) -> list[list['Experiment']]: # noqa
         """
-        Creates list of Experiment objecst from a list of individual
+        Creates list of Experiment objects from a list of individual
         Measurement objects. Experiments are defined as a set of measurements
         with the same temperature and DC field strength
 
@@ -1798,9 +1790,9 @@ class Experiment():
         ----------
         measurement: list[Measurement]
             Measurements at various temperatures and DC fields
-        temp_thresh: float, default 0.1
+        temp_thresh: float, default 0.1 K
             Threshold used to discriminate between temperatures
-        field_thresh: float, default 1e-8
+        field_thresh: float, default 1 Oe
             Threshold used to discriminate between dc field values
 
         Returns
@@ -1816,39 +1808,49 @@ class Experiment():
             The sublists are sorted low to high mean temperature.
         """ # noqa
 
-        # Sort measurements by dc field
+        # Sort measurements by dc field then temperature
         measurements.sort(key=lambda k: (k.dc_field, k.temperature))
 
-        # Find values for which dc field step size is >= field_thresh Oe
-        mask = np.abs(
-            np.diff([measurement.dc_field for measurement in measurements])
-        ) >= field_thresh
-        # and mark indices at which to split
-        split_ind = np.where(mask)[0]
+        mean_fields, split_ind = find_mean_values(
+            [
+                measurement.dc_field
+                for measurement in measurements
+            ],
+            thresh=field_thresh
+        )
 
+        # Set each measurement's "mean", or representative field
+        for measurement, mean_field in zip(measurements, np.concatenate(mean_fields)): # noqa
+            measurement.mean_dc_field = mean_field
+
+        # Re-sort using mean dc field
+        measurements.sort(key=lambda k: (k.mean_dc_field, k.temperature))
+
+        # And split based on changing dc field values
         measurements: list[list[Measurement]] = np.split(
             measurements, split_ind + 1
         )
 
+        # Back to list...
         measurements = [measurements.tolist() for measurements in measurements]
 
         experiments = []
 
         for sf_measurments in measurements:
 
-            mean_temps, split_ind = find_mean_temperatures(
+            mean_temps, split_ind = find_mean_values(
                 [
                     measurement.temperature
                     for measurement in sf_measurments
                 ],
-                temp_thresh=temp_thresh
+                thresh=temp_thresh
             )
 
             # Set each measurement's "mean", or representative temperature
             for measurement, mean_temp in zip(sf_measurments, np.concatenate(mean_temps)): # noqa
-                measurement.set_mean_temp(mean_temp)
+                measurement.mean_temperature = mean_temp
 
-            # sort measurements by temperature, then by ac frequency
+            # sort measurements by ac frequency
             sf_measurments.sort(
                 key=lambda k: (k.mean_temperature, k.ac_freq)
             )
@@ -1917,8 +1919,8 @@ class Experiment():
                             save: bool = True) -> None:
         """
 
-        Creates plot of in- and out-of-phase susceptibilities
-        as matplotlib figure
+        Creates plot of in- and out-of-phase raw susceptibilities as matplotlib
+        figure
 
         Parameters
         ----------
@@ -1953,7 +1955,7 @@ class Experiment():
 
             # Real
             ax1.semilogx(
-                experiment.ac_freq*2*np.pi,
+                experiment.ac_freq,
                 experiment.sus_re,
                 '-o',
                 markersize=4,
@@ -1963,7 +1965,7 @@ class Experiment():
             )
             # Imaginary
             ax2.semilogx(
-                experiment.ac_freq*2*np.pi,
+                experiment.ac_freq,
                 experiment.sus_im,
                 '-o',
                 markersize=4,
