@@ -59,7 +59,7 @@ def ac_mode_func(args):
             sys.exit(message)
 
     # Get file headers
-    header_indices, header_names, headers_supported = ac.parse_headers(
+    header_indices, header_names = ac.parse_headers(
         user_cfg.file_name, data_line
     )
 
@@ -69,11 +69,11 @@ def ac_mode_func(args):
         for ind, name in zip(header_indices.values(), header_names.keys()):
             if ind == -1:
                 message += '\n {} column not found.'.format(name.upper())
-                message += '\n  Options for expected header are: '
-                for i in headers_supported[name]:
+                message += '\n  Supported headers for this column are: '
+                for i in ac.HEADERS_SUPPORTED[name]:
                     message += '\n   {} '.format(i)
         message += '\nManually change the input file or contact'
-        message += ' danielreta1@gmail.com to implement new headers.\n'
+        message += ' danielreta1@gmail.com to implement new headers\n'
         if args.ccfit2_exe:
             gui.error_box(message)
         else:
@@ -85,8 +85,7 @@ def ac_mode_func(args):
     )
 
     # Change of units of input susceptibility to cm^3mol^(-1)
-    imaginary_sus = list(header_indices.keys())[3]
-    if header_names[imaginary_sus] in ['AC X" (emu/Oe)', "AC X'' (emu/Oe)"]:
+    if header_names["sus_imaginary"] in ['AC X" (emu/Oe)', "AC X'' (emu/Oe)"]:
         in_susc_units = "emu/Oe"
     else:
         in_susc_units = "emu"
@@ -108,8 +107,8 @@ def ac_mode_func(args):
         print('\nVerbose mode entered.\n')
         for experiments in all_experiments_sep:
             print('Field: {} Oe'.format(experiments[0].dc_field))
-            print('The raw temperatures at this field have been grouped as:') # noqa
             for experiment in experiments:
+                print('The raw temperatures at this field have been grouped as:') # noqa
                 print(
                     'Mean={:04.1f}, Min={}, Max={}\nRaw={}'.format(
                         experiment.temperatures[0],
@@ -135,12 +134,12 @@ def ac_mode_func(args):
             ac.Experiment.plot_colecole(
                 experiments,
                 save_dir=user_cfg.results_dir,
-                file_head="ac"
+                file_head="raw"
             )
             ac.Experiment.plot_susceptibility(
                 experiments,
                 save_dir=user_cfg.results_dir,
-                file_head="ac"
+                file_head="raw"
             )
         exit()
 
@@ -155,7 +154,7 @@ def ac_mode_func(args):
     for experiments, dc_field in zip(all_experiments_sep, unique_dc_fields):
 
         # Creates models for current experiments
-        models = ac.Model.from_experiments(experiments, verbose=True)
+        models = ac.Model.from_experiments(experiments, verbose=False)
         # Update flat lines threshold
         for model in models:
             model.flat_thresh = args.flat_thresh
@@ -235,12 +234,11 @@ def ac_mode_func(args):
             'at {} Oe\n'.format(dc_field)
         )
 
-
         if np.sum([model.fit_status for model in models]) <= 2:
             print(
                 '    ***Warning***:\n    Not enough data points to',
                 'fit the relaxation profile'
-            )   
+            )
             continue
 
         if isinstance(models[0], ac.TwoMaximaModel):
@@ -276,7 +274,8 @@ def ac_mode_func(args):
         )
 
         relax.select_model_rates(
-            rxp, temperature, 1./tau, dc_field, _process='tau_vs_T', zf_options=True
+            rxp, temperature, 1./tau, dc_field,
+            _process='tau_vs_T', zf_options=True
         )
     return
 
@@ -615,8 +614,8 @@ def read_args(arg_list=None):
         '--field_thresh',
         metavar='<float>',
         type=float,
-        default=1e-8,
-        help='Threshold used to discriminate between DC Fields, default 1e-8 Oe' # noqa
+        default=1,
+        help='Threshold used to discriminate between DC Fields, default 1 Oe' # noqa
     )
     ac_parser.add_argument(
         '--select_T',
