@@ -32,7 +32,7 @@ class Process_Waveform():
         self.applied_field = user_args.field
         self.field_window = user_args.field_window
         self.filenumber = 0
-        self.data_pointer = user_args.data_pointer
+        self.data_header = user_args.data_header
         self.show = user_args.show
         # Get the number of frequencies to be discarded.
         # self.discard_freq = user_args.discard_freq
@@ -176,14 +176,14 @@ class Process_Waveform():
             for line in f:
                 data_starts_from += 1
                 # If [Data] containing line reached, add one (headers) and exit
-                if self.data_pointer in line:
+                if self.data_header in line:
                     data_starts_from += 1
                     break
                 else:
                     data_section = True
         if not data_section:
             raise ValueError(
-                "Data section cannot be found. Check --data_pointer argument."
+                "Data section cannot be found. Check --data_header argument."
             )
 
         # Read in data using the user-defined columns. Note -1 as index starts
